@@ -35,7 +35,7 @@ get_random <- function(x) {
 #' @export
 get_random.default <- function(x) {
   if (is_empty_object(find_random(x))) {
-    warning("No random effects found in model.", call. = FALSE)
+    format_warning("No random effects found in model.")
     return(NULL)
   }
 
